@@ -102,8 +102,20 @@ def lgb_model_skl(X_train,y_train,X_test,y_test,metric='average_precision',param
 
 def lgb_model_train(X_train,y_train,X_test,y_test,params=None,num_rounds=None,early_stop=None,log=None):
 
-    d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=[])
-    d_valid = lgb.Dataset(X_test, label=y_test, categorical_feature=[])
+    
+    if 'max_bin' in params:
+        
+        max_bin=params['max_bin']  
+        print("Estableciendo max_bin : ",max_bin)
+        del params['max_bin']
+        d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=[], params={"max_bin":max_bin})
+        d_valid = lgb.Dataset(X_test, label=y_test, categorical_feature=[], params={"max_bin":max_bin})
+    else:
+        d_train = lgb.Dataset(X_train, label=y_train, categorical_feature=[])
+        d_valid = lgb.Dataset(X_test, label=y_test, categorical_feature=[])
+        
+
+
 
     watchlist = [d_valid]
     
