@@ -30,6 +30,8 @@ from sklearn.metrics import precision_recall_fscore_support
 from lightgbm import early_stopping
 from lightgbm import log_evaluation
 import statistics
+from sklearn.metrics import f1_score
+
 
 def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=None, list_kpi=[], n_jobs=None, metric=None, num_rounds=None,early_stop=None,log=None,random_state=42):
     folds = 5
@@ -132,7 +134,7 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         #list_TN_train_opt.append(kpi["train/TN_opt"])  
         #list_FN_train_opt.append(kpi["train/FN_opt"]) 
 
-        list_valid_score.append(kpi["valid/average_precision"])
+        list_valid_score.append(kpi["valid/score"])
         
         list_valid_precision.append(kpi["valid/precision"])
         list_valid_recall.append(kpi["valid/recall"])
@@ -362,6 +364,13 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
     list_kpi.append(result_iter)
     return mean_valid_score
 
+
+def lgb_f1_score(y_hat, data):
+    y_true = data.get_label()
+    y_hat = np.round(y_hat) # scikits f1 doesn't like probabilities
+    return 'f1', f1_score(y_true, y_hat), True
+
+
 def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_features=None,metric=None,n_jobs=1, num_rounds=None,early_stop=None,log=None,random_state=None ):
     """Train Light GBM model"""    
     X_train, y_train = train
@@ -385,23 +394,25 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
     watchlist = [d_valid]    
 
     
-    pruning_callback_v = optuna.integration.LightGBMPruningCallback(trial, "average_precision",
-                                                                  valid_name="data_valid")
+    pruning_callback_v = optuna.integration.LightGBMPruningCallback(trial, metric, valid_name="data_valid")
     
     model = lgb.train(train_params,                 
                       num_boost_round = num_rounds,
                       train_set=d_train,
                       valid_names = ['data_valid'],
                       valid_sets=watchlist,
+                      feval=lgb_f1_score,
                       callbacks=[log_evaluation(log),pruning_callback_v,early_stopping(early_stop)]
                      )
+    
+    valid_best_score = model.best_score['data_valid'][metric]
 
     # predictions
     
     y_pred_prob_train = model.predict(X_train, num_iteration=model.best_iteration)   
     y_pred_prob_valid = model.predict(X_valid, num_iteration=model.best_iteration) 
     
-    
+    print('best_score== : ', model.best_score)
     
     y_pred_train = np.rint(y_pred_prob_train)    
     #opt_threshold_train  = g.get_opt_threshold(y_train,y_pred_prob_train)
@@ -453,6 +464,8 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
            #'train/TN_opt': TN_train_opt,   
            #'train/FN_opt': FN_train_opt,  
            
+           'valid/score': valid_best_score,
+           
            'valid/average_precision': valid_average_precision,
            'valid/precision': precision,
            'valid/recall': recall,
